@@ -143,7 +143,7 @@ var searchData=
   ['tds_5fget_5fdata_5finfo_140',['tds_get_data_info',['../a00595.html#gad9b6b86f48be077fb44ac603845a0c27',1,'token.c']]],
   ['tds_5fget_5fdynid_141',['tds_get_dynid',['../a00592.html#ga93503e64091b51add0801abebe22abf4',1,'mem.c']]],
   ['tds_5fget_5flocale_142',['tds_get_locale',['../a00431.html#a41390fa6e1083ba84fb523797e6b5275',1,'locale.c']]],
-  ['tds_5fget_5fn_143',['tds_get_n',['../a00594.html#gae777dd57e8d1bb40349d7d7d8434fddf',1,'tds_get_n(TDSSOCKET *tds, void *dest, size_t n):&#160;read.c'],['../a00594.html#gae777dd57e8d1bb40349d7d7d8434fddf',1,'tds_get_n(TDSSOCKET *tds, void *dest, size_t need):&#160;read.c']]],
+  ['tds_5fget_5fn_143',['tds_get_n',['../a00594.html#gae777dd57e8d1bb40349d7d7d8434fddf',1,'tds_get_n(TDSSOCKET *tds, void *dest, size_t need):&#160;read.c'],['../a00594.html#gae777dd57e8d1bb40349d7d7d8434fddf',1,'tds_get_n(TDSSOCKET *tds, void *dest, size_t n):&#160;read.c']]],
   ['tds_5fget_5fnull_5ftype_144',['tds_get_null_type',['../a00590.html#ga68e3a76fd7b0a77614765826a8ab5be8',1,'tds_get_null_type(TDS_SERVER_TYPE srctype):&#160;convert.c'],['../a00590.html#ga68e3a76fd7b0a77614765826a8ab5be8',1,'tds_get_null_type(TDS_SERVER_TYPE srctype):&#160;convert.c']]],
   ['tds_5fget_5fsize_5fby_5ftype_145',['tds_get_size_by_type',['../a00431.html#a4c070147d189dede5e08a2dc66852678',1,'tds_types.h']]],
   ['tds_5fget_5fsocket_5ferror_146',['tds_get_socket_error',['../a00594.html#ga4a2418e0a4533d616ef3da526236f2b8',1,'net.c']]],
@@ -225,7 +225,7 @@ var searchData=
   ['tds_5fprocess_5fsimple_5fquery_222',['tds_process_simple_query',['../a00595.html#gaeeb1562044786ea17bea361ed83e6946',1,'tds_process_simple_query(TDSSOCKET *tds):&#160;token.c'],['../a00595.html#gaeeb1562044786ea17bea361ed83e6946',1,'tds_process_simple_query(TDSSOCKET *tds):&#160;token.c']]],
   ['tds_5fprocess_5ftabname_223',['tds_process_tabname',['../a00595.html#gaeec59bca9bd0c5388e245f0d19d9c81a',1,'token.c']]],
   ['tds_5fprocess_5ftokens_224',['tds_process_tokens',['../a00595.html#gabfc9de1d1fe718818caf63a4be4035a6',1,'tds_process_tokens(TDSSOCKET *tds, TDS_INT *result_type, int *done_flags, unsigned flag):&#160;token.c'],['../a00595.html#gabfc9de1d1fe718818caf63a4be4035a6',1,'tds_process_tokens(TDSSOCKET *tds, TDS_INT *result_type, int *done_flags, unsigned flag):&#160;token.c']]],
-  ['tds_5fprtype_225',['tds_prtype',['../a00595.html#ga307f949194204f71f1a7e574424048b1',1,'tds_prtype(int token):&#160;token.c'],['../a00595.html#ga307f949194204f71f1a7e574424048b1',1,'tds_prtype(int type):&#160;token.c']]],
+  ['tds_5fprtype_225',['tds_prtype',['../a00595.html#ga307f949194204f71f1a7e574424048b1',1,'tds_prtype(int type):&#160;token.c'],['../a00595.html#ga307f949194204f71f1a7e574424048b1',1,'tds_prtype(int token):&#160;token.c']]],
   ['tds_5fput_5fdata_226',['tds_put_data',['../a00593.html#ga9fcc0a3932dcad530511395ef8a767fb',1,'query.c']]],
   ['tds_5fput_5fdata_5finfo_227',['tds_put_data_info',['../a00593.html#gafd74652c4722ddce4d642cc4209449d4',1,'query.c']]],
   ['tds_5fput_5fn_5fas_5fucs2_228',['TDS_PUT_N_AS_UCS2',['../a00593.html#ga62c3dc9946acb3ffd1b7ae43424f5b47',1,'query.c']]],
@@ -241,7 +241,7 @@ var searchData=
   ['tds_5fquoteout_5fstream_238',['tds_quoteout_stream',['../a00809.html',1,'']]],
   ['tds_5fraw_5fmutex_239',['tds_raw_mutex',['../a01349.html',1,'']]],
   ['tds_5fread_5fconf_5ffile_240',['tds_read_conf_file',['../a00589.html#ga4799b423b5d982dbc8f31b7738255eef',1,'tds_read_conf_file(TDSLOGIN *login, const char *server):&#160;config.c'],['../a00589.html#ga4799b423b5d982dbc8f31b7738255eef',1,'tds_read_conf_file(TDSLOGIN *login, const char *server):&#160;config.c']]],
-  ['tds_5fread_5fconf_5fsection_241',['tds_read_conf_section',['../a00589.html#ga44fdbe16827097d947f900d96003de98',1,'tds_read_conf_section(FILE *in, const char *section, TDSCONFPARSE tds_conf_parse, void *parse_param):&#160;config.c'],['../a00589.html#ga44fdbe16827097d947f900d96003de98',1,'tds_read_conf_section(FILE *in, const char *section, TDSCONFPARSE tds_conf_parse, void *param):&#160;config.c']]],
+  ['tds_5fread_5fconf_5fsection_241',['tds_read_conf_section',['../a00589.html#ga44fdbe16827097d947f900d96003de98',1,'tds_read_conf_section(FILE *in, const char *section, TDSCONFPARSE tds_conf_parse, void *param):&#160;config.c'],['../a00589.html#ga44fdbe16827097d947f900d96003de98',1,'tds_read_conf_section(FILE *in, const char *section, TDSCONFPARSE tds_conf_parse, void *parse_param):&#160;config.c']]],
   ['tds_5fread_5fconfig_5finfo_242',['tds_read_config_info',['../a00589.html#ga9ff2436ea56ddcdecf984acf46ce4b90',1,'tds_read_config_info(TDSSOCKET *tds, TDSLOGIN *login, TDSLOCALE *locale):&#160;config.c'],['../a00589.html#ga9ff2436ea56ddcdecf984acf46ce4b90',1,'tds_read_config_info(TDSSOCKET *tds, TDSLOGIN *login, TDSLOCALE *locale):&#160;config.c']]],
   ['tds_5fread_5finterfaces_243',['tds_read_interfaces',['../a00589.html#ga66de78d379cad2ee3d6c26948ad6445f',1,'config.c']]],
   ['tds_5fread_5fnamelist_244',['tds_read_namelist',['../a00595.html#gaeaaed2ea1d8c827da1a0f5b419524ae1',1,'token.c']]],
@@ -345,26 +345,25 @@ var searchData=
   ['tdsnumeric_342',['tdsnumeric',['../a01125.html',1,'']]],
   ['tdsoldmoney_343',['tdsoldmoney',['../a01129.html',1,'']]],
   ['tdspbcb_344',['TDSPBCB',['../a00254.html#af31a5af3c7480dc3a16576dfc84f3b06',1,'bulk.c']]],
-  ['tdsresultinfo_345',['TDSRESULTINFO',['../a00431.html#a1efbb2f3844cb2ea89af03721ac67277',1,'tds.h']]],
-  ['tdsunique_346',['tdsunique',['../a01149.html',1,'']]],
-  ['tdsvariant_347',['TDSVARIANT',['../a00431.html#a25488abe3449d4cdaaa97587d34f9174',1,'tds.h']]],
-  ['tdsvername_5ft_348',['tdsvername_t',['../a00777.html',1,'']]],
-  ['term_5flen_349',['term_len',['../a00757.html#aae893302d33ee1e9d83c3d85d7390dca',1,'tds_file_stream']]],
-  ['terminator_350',['terminator',['../a00757.html#a463c28a7d862c0a6d7bf3170dd614dc0',1,'tds_file_stream']]],
-  ['the_20db_20lib_20api_351',['The db-lib API',['../a00577.html',1,'']]],
-  ['time_352',['time',['../a01205.html#afd6a58ec251f2c08a040917ba5a8cd3f',1,'TDS_DATETIMEALL::time'],['../a01429.html#a6bb5dcd5b47813b71934546e0c60e035',1,'DBDATETIMEALL::time']]],
-  ['timezone_353',['timezone',['../a01209.html#a624e21e65d0ae89797b3a7eadc48829f',1,'tdsdaterec']]],
-  ['tm_5fhour_354',['tm_hour',['../a00781.html#a6ece03e77f69035da83d5739e16ef905',1,'tds_time']]],
-  ['tm_5fmday_355',['tm_mday',['../a00781.html#a8dfc26d484c247040f521f20288651f1',1,'tds_time']]],
-  ['tm_5fmin_356',['tm_min',['../a00781.html#ab50f30e05dc6b493d347918ab7ded1e9',1,'tds_time']]],
-  ['tm_5fmon_357',['tm_mon',['../a00781.html#adce28126e9bbd4ef005e3bf181d59745',1,'tds_time']]],
-  ['tm_5fns_358',['tm_ns',['../a00781.html#a386f1cfcabbe3ed86afe72bed75778cf',1,'tds_time']]],
-  ['tm_5fsec_359',['tm_sec',['../a00781.html#adeb5e3f535662c0341d28f8d669cb59b',1,'tds_time']]],
-  ['tm_5fyear_360',['tm_year',['../a00781.html#a3e27d50ebb5196356a6a8a9b495c8758',1,'tds_time']]],
-  ['tmp_5fbuf_361',['tmp_buf',['../a00645.html',1,'']]],
-  ['tmp_5fcol_5fstruct_362',['tmp_col_struct',['../a00741.html',1,'']]],
-  ['to_20add_20a_20new_20type_363',['How to add a new type',['../a01462.html',1,'']]],
-  ['todo_20list_364',['Todo List',['../a00575.html',1,'']]],
-  ['token_2ec_365',['token.c',['../a00251.html',1,'']]],
-  ['type_366',['type',['../a01462.html',1,'How to add a new type'],['../a01285.html#a889aafdde1d57c9be0585326022831f0',1,'tds_cursor::type']]]
+  ['tdsunique_345',['tdsunique',['../a01149.html',1,'']]],
+  ['tdsvariant_346',['TDSVARIANT',['../a00431.html#a25488abe3449d4cdaaa97587d34f9174',1,'tds.h']]],
+  ['tdsvername_5ft_347',['tdsvername_t',['../a00777.html',1,'']]],
+  ['term_5flen_348',['term_len',['../a00757.html#aae893302d33ee1e9d83c3d85d7390dca',1,'tds_file_stream']]],
+  ['terminator_349',['terminator',['../a00757.html#a463c28a7d862c0a6d7bf3170dd614dc0',1,'tds_file_stream']]],
+  ['the_20db_20lib_20api_350',['The db-lib API',['../a00577.html',1,'']]],
+  ['time_351',['time',['../a01205.html#afd6a58ec251f2c08a040917ba5a8cd3f',1,'TDS_DATETIMEALL::time'],['../a01429.html#a6bb5dcd5b47813b71934546e0c60e035',1,'DBDATETIMEALL::time']]],
+  ['timezone_352',['timezone',['../a01209.html#a624e21e65d0ae89797b3a7eadc48829f',1,'tdsdaterec']]],
+  ['tm_5fhour_353',['tm_hour',['../a00781.html#a6ece03e77f69035da83d5739e16ef905',1,'tds_time']]],
+  ['tm_5fmday_354',['tm_mday',['../a00781.html#a8dfc26d484c247040f521f20288651f1',1,'tds_time']]],
+  ['tm_5fmin_355',['tm_min',['../a00781.html#ab50f30e05dc6b493d347918ab7ded1e9',1,'tds_time']]],
+  ['tm_5fmon_356',['tm_mon',['../a00781.html#adce28126e9bbd4ef005e3bf181d59745',1,'tds_time']]],
+  ['tm_5fns_357',['tm_ns',['../a00781.html#a386f1cfcabbe3ed86afe72bed75778cf',1,'tds_time']]],
+  ['tm_5fsec_358',['tm_sec',['../a00781.html#adeb5e3f535662c0341d28f8d669cb59b',1,'tds_time']]],
+  ['tm_5fyear_359',['tm_year',['../a00781.html#a3e27d50ebb5196356a6a8a9b495c8758',1,'tds_time']]],
+  ['tmp_5fbuf_360',['tmp_buf',['../a00645.html',1,'']]],
+  ['tmp_5fcol_5fstruct_361',['tmp_col_struct',['../a00741.html',1,'']]],
+  ['to_20add_20a_20new_20type_362',['How to add a new type',['../a01462.html',1,'']]],
+  ['todo_20list_363',['Todo List',['../a00575.html',1,'']]],
+  ['token_2ec_364',['token.c',['../a00251.html',1,'']]],
+  ['type_365',['type',['../a01462.html',1,'How to add a new type'],['../a01285.html#a889aafdde1d57c9be0585326022831f0',1,'tds_cursor::type']]]
 ];
